==> hoteldruid-mod-fr_2.3.1-1.tar.gz: fr/crearegole.php <==
<?php

switch ($messaggio) {

case "Inserisci le regole di assegnazione per le prenotazioni dell'anno":	$messaggio = "Insérez les règles d'attribution pour les réservations de l'année"; break;
case "Regola di assegnazione":  					$messaggio = "Règle d'attribution"; break;
case "nel periodo dal":  							$messaggio = "dans la période de"; break;
case "al":  										$messaggio = "à"; break;
case "Inserisci la regola":  						$messaggio = "Insérez la règle"; break;
case "Cancella tutte le regole di questo tipo":		$messaggio = "Supprimez toutes les règles de ce type"; break;
case "Quando si sceglie la tariffa":  				$messaggio = "Lorsque on choisit le tarif"; break;
case "se non si inserisce nessun altro metodo di assegnazione":	$messaggio = "si on n'insère aucune autre méthode d'attribution"; break;
case "Vedi le regole già inserite":  							$messaggio = "Voir les règles déjà insérées"; break;
case "Torna al menù principale":  								$messaggio = "Retour au menu principal"; break;
case "Non sono stati inseriti tutti i dati necessari":			$messaggio = "Toutes les données nécessaires n'ont pas été insérées"; break;
case "Le date sono sbagliate":  					$messaggio = "Les dates sont erronées"; break;
case "opzionale":  									$messaggio = "facultatif"; break;
case "La regola è stata inserita":  				$messaggio = "La règle a été insérée"; break;
case "Sei sicuro di voler cancellare tutte le regole del tipo 1":	$messaggio = "Etes vous certain de vouloir supprimer toutes les règles de type 1"; break;
case "SI":  										$messaggio = "Oui"; break;
case "Le regole sono state cancellate":  			$messaggio = "Les règles ont été supprimées"; break;
case "Si deve scegliere la tariffa":  				$messaggio = "On doit choisir le tarif"; break;
case " non esiste":  								$messaggio = " n'existe pas"; break;
case "Torna indietro":  							$messaggio = "Retournez"; break;
case "Motivazione non valida":  					$messaggio = "Motivation pas valide"; break;
case "La tariffa scelta ha già un utente associato, cancella la regola prima di inserirne una nuova":	$messaggio = "Le tarif choisi a déjà un utilisateur associé, supprimez la règle avant d'en insérer une nouvelle"; break;
case "Quando l'utente amministratore":  			$messaggio = "Quand l'utilisateur administrateur"; break;
case "sceglie la tariffa":  						$messaggio = "choisit le tarif"; break;
case "fai risultare come se l'utente":  			$messaggio = "montrez comme si l'utilisateur"; break;
case "avesse inserito la prenotazione e l'eventuale cliente":	$messaggio = "il avait inséré la réservation et l'eventuel client"; break;
case "Si deve inserire l'utente da associare":		$messaggio = "On doit insérer l'ustilisateur à associer"; break;
case "L'utente ":  									$messaggio = "L'utilisateur "; break;
case "motivazione":  				$messaggio = "motivation"; break;
case "Inserisci o modifica la regola":  	$messaggio = "Insert or modify rule"; break;
case "La regola di assegnazione":		$messaggio = "The assignment rule"; break;
case "è stata inserita":			$messaggio = "has been inserted"; break;
case "è stata modificata":			$messaggio = "has been modified"; break;
case "assegna automaticamente come numero di persone":	$messaggio = "automatically assign as number of people"; break;
case "se non si inserisce nessun altro numero":	$messaggio = "if no other number is inserted"; break;
case "La tariffa scelta ha già un numero di persone associato, cancella la regola prima di inserirne una nuova":	$messaggio = "The choosen rate has already an assigned number of people, delete the rule before inserting a new one"; break;
case "Si deve inserire il numero di persone da associare":	$messaggio = "You have to choose the number of people to be associated"; break;
case "Eccezioni alla regola":  			$messaggio = "Exceptions to rule"; break;
case "e mancano meno di":  			$messaggio = " and less than"; break;
case "giorni":					$messaggio = "days are missing"; break;
case "dall'inizio":				$messaggio = "from the beginning"; break;
case "dalla fine":				$messaggio = "from the ending"; break;
case "della prenotazione quando essa viene inserita, allora":	$messaggio = "of the reservation when it is inserted, then"; break;
case "Inserisci o modifica questa eccezione alla regola":	$messaggio = "Insert or modify this exception to rule"; break;
case "Si deve inserire il numero di giorni":  	$messaggio = "The number of days must be inserted"; break;
case "Chiedi prima di assegnare":		$messaggio = "Ask before assigning"; break;
case "Chiudi":  				$messaggio = "Close"; break;
case "Il periodo chiuso è stato liberato dalle prenotazioni":	$messaggio = "The closed period has been freed of reservations"; break;
case "<span class=\"colred\">Non è stato possibile</span> liberare dalle prenotazioni il periodo chiuso":	$messaggio = "<span class=\"colred\">It was not possible</span> to free from reservations the closed period"; break;
case "per le tariffe":  			$messaggio = "for rates"; break;
case "Esiste già una regola di questo tipo nel periodo selezionato":	$messaggio = "A rule of this kind already exists for the selected period"; break;
case "assegna automaticamente":  		$messaggio = "automatically assign"; break;
case "tra":  					$messaggio = "between"; break;
case "da assegnare troppo alto, supera quello presente nella lista":	$messaggio = "to be assigned too high, exceeds the number in the list"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "della regola 2 mancanti nella eccezione alla regola":	$messaggio = "in rule 2 that are missing from the exception to the rule"; break;
case "nella regola 2 di questa tariffa che non possono ospitare":	$messaggio = "in the rule 2 for this rate that can't host"; break;
case "persone":  				$messaggio = "people"; break;
case "nella regola di assegnazione 2 di questa tariffa":	$messaggio = "in the assignment rule 2 for this rate"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-fr_3.0.8-1.tar.gz: fr/crearegole.php <==
<?php

switch ($messaggio) {

case "Inserisci le regole di assegnazione per le prenotazioni dell'anno":	$messaggio = "Insérez les règles d'attribution pour les réservations de l'année"; break;
case "Regola di assegnazione":  					$messaggio = "Règle d'attribution"; break;
case "nel periodo dal":  							$messaggio = "dans la période de"; break;
case "al":  										$messaggio = "à"; break;
case "Inserisci la regola":  						$messaggio = "Insérez la règle"; break;
case "Cancella tutte le regole di questo tipo":		$messaggio = "Supprimez toutes les règles de ce type"; break;
case "Quando si sceglie la tariffa":  				$messaggio = "Lorsque on choisit le tarif"; break;
case "se non si inserisce nessun altro metodo di assegnazione":	$messaggio = "si on n'insère aucune autre méthode d'attribution"; break;
case "Vedi le regole già inserite":  							$messaggio = "Voir les règles déjà insérées"; break;
case "Torna al menù principale":  								$messaggio = "Retour au menu principal"; break;
case "Non sono stati inseriti tutti i dati necessari":			$messaggio = "Toutes les données nécessaires n'ont pas été insérées"; break;
case "Le date sono sbagliate":  					$messaggio = "Les dates sont erronées"; break;
case "opzionale":  									$messaggio = "facultatif"; break;
case "La regola è stata inserita":  				$messaggio = "La règle a été insérée"; break;
case "Sei sicuro di voler cancellare tutte le regole del tipo 1":	$messaggio = "Etes vous certain de vouloir supprimer toutes les règles de type 1"; break;
case "SI":  										$messaggio = "Oui"; break;
case "Le regole sono state cancellate":  			$messaggio = "Les règles ont été supprimées"; break;
case "Si deve scegliere la tariffa":  				$messaggio = "On doit choisir le tarif"; break;
case " non esiste":  								$messaggio = " n'existe pas"; break;
case "Torna indietro":  							$messaggio = "Retournez"; break;
case "Motivazione non valida":  					$messaggio = "Motivation pas valide"; break;
case "La tariffa scelta ha già un utente associato, cancella la regola prima di inserirne una nuova":	$messaggio = "Le tarif choisi a déjà un utilisateur associé, supprimez la règle avant d'en insérer une nouvelle"; break;
case "Quando l'utente amministratore":  			$messaggio = "Quand l'utilisateur administrateur"; break;
case "sceglie la tariffa":  						$messaggio = "choisit le tarif"; break;
case "fai risultare come se l'utente":  			$messaggio = "montrez comme si l'utilisateur"; break;
case "avesse inserito la prenotazione e l'eventuale cliente":	$messaggio = "il avait inséré la réservation et l'eventuel client"; break;
case "Si deve inserire l'utente da associare":		$messaggio = "On doit insérer l'ustilisateur à associer"; break;
case "L'utente ":  									$messaggio = "L'utilisateur "; break;
case "Crea Regole":  				$messaggio = "Create Rules"; break;
case "motivazione":  				$messaggio = "motivation"; break;
case "Inserisci o modifica la regola":  	$messaggio = "Insert or modify rule"; break;
case "La regola di assegnazione":		$messaggio = "The assignment rule"; break;
case "è stata inserita":			$messaggio = "has been inserted"; break;
case "è stata modificata":			$messaggio = "has been modified"; break;
case "assegna automaticamente come numero di persone":	$messaggio = "automatically assign as number of people"; break;
case "se non si inserisce nessun altro numero":	$messaggio = "if no other number is inserted"; break;
case "La tariffa scelta ha già un numero di persone associato, cancella la regola prima di inserirne una nuova":	$messaggio = "The choosen rate has already an assigned number of people, delete the rule before inserting a new one"; break;
case "Si deve inserire il numero di persone da associare":	$messaggio = "You have to choose the number of people to be associated"; break;
case "Eccezioni alla regola":  			$messaggio = "Exceptions to rule"; break;
case "e mancano meno di":  			$messaggio = " and less than"; break;
case "giorni":					$messaggio = "days are missing"; break;
case "dall'inizio":				$messaggio = "from the beginning"; break;
case "dalla fine":				$messaggio = "from the ending"; break;
case "della prenotazione quando essa viene inserita, allora":	$messaggio = "of the reservation when it is inserted, then"; break;
case "Inserisci o modifica questa eccezione alla regola":	$messaggio = "Insert or modify this exception to rule"; break;
case "Si deve inserire il numero di giorni":  	$messaggio = "The number of days must be inserted"; break;
case "Chiedi prima di assegnare":		$messaggio = "Ask before assigning"; break;
case "Chiudi":  				$messaggio = "Close"; break;
case "Il periodo chiuso è stato liberato dalle prenotazioni":	$messaggio = "The closed period has been freed of reservations"; break;
case "<span class=\"colred\">Non è stato possibile</span> liberare dalle prenotazioni il periodo chiuso":	$messaggio = "<span class=\"colred\">It was not possible</span> to free from reservations the closed period"; break;
case "per le tariffe":  			$messaggio = "for rates"; break;
case "Esiste già una regola di questo tipo nel periodo selezionato":	$messaggio = "A rule of this kind already exists for the selected period"; break;
case "assegna automaticamente":  		$messaggio = "automatically assign"; break;
case "tra":  					$messaggio = "between"; break;
case "da assegnare troppo alto, supera quello presente nella lista":	$messaggio = "to be assigned too high, exceeds the number in the list"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "della regola 2 mancanti nella eccezione alla regola":	$messaggio = "in rule 2 that are missing from the exception to the rule"; break;
case "nella regola 2 di questa tariffa che non possono ospitare":	$messaggio = "in the rule 2 for this rate that can't host"; break;
case "persone":  				$messaggio = "people"; break;
case "nella regola di assegnazione 2 di questa tariffa":	$messaggio = "in the assignment rule 2 for this rate"; break;
case "Regole esistenti":  			$messaggio = "Existing rules"; break;
case "Cancella o ridimensiona queste regole":  	$messaggio = "Delete or scale down these rules"; break;
case "Cancella":  				$messaggio = "Delete"; break;
case "Ridimensiona":  				$messaggio = "Scale down"; break;
case "Modifica la regola":  			$messaggio = "Modify rule"; break;
case "chiusure":  				$messaggio = "closures"; break;
case "numero di persone":  			$messaggio = "number of people"; break;
case "utente inserimento":  			$messaggio = "inserting user"; break;
case "non permettere l'inserimento di prenotazioni con meno di":	$messaggio = "do not allow inserting reservations with less than"; break;
case "Il numero di persone minimo":  		$messaggio = "The minimum number of people"; break;
case "è maggiore del numero di persone predefinito":	$messaggio = "is bigger then the default number of people"; break;
case "è stata cancellata":  			$messaggio = "has been deleted"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
